@@ -45,13 +45,10 @@ class FerhassioSaver:
         transaction_start_time = time.time()
 
         if cnt:
-            job = self.database.aql.execute(f"FOR doc IN {self.async_coll.name} "
-                                            f"LIMIT {cnt} "
-                                            f"RETURN doc{'.'+ field if field else ''}")
-        else:
-            job = self.database.aql.execute(f"FOR doc IN {self.async_coll.name} "
-                                            f"RETURN doc{'.'+ field if field else ''}")
+            job = self.database.aql.execute(f"FOR doc IN {self.async_coll.name} LIMIT {cnt} SORT doc._key ASC RETURN doc{'.'+ field if field else ''}")
 
+        else:
+            job = self.database.aql.execute(f"FOR doc IN {self.async_coll.name} RETURN doc{'.'+ field if field else ''}")
 
         fetched_data = [document for document in job]
 
@@ -132,4 +129,4 @@ class FerhassioSaver:
         Get element count in selected connected collection
         :return: Elements count
         """
-        return self.database.collection(self.coll_name).count()
\ No newline at end of file
+        return self.database.collection(self.coll_name).count()
